"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.compliance_job_script import ComplianceJobScript
    from delphix.api.gateway.model.tag import Tag
    globals()['ComplianceJobScript'] = ComplianceJobScript
    globals()['Tag'] = Tag


class CreateComplianceJobRequest(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('type',): {
            'MASKING': "MASKING",
            'DISCOVERY': "DISCOVERY",
            'TOKENIZATION': "TOKENIZATION",
            'REIDENTIFICATION': "REIDENTIFICATION",
        },
    }

    validations = {
        ('max_memory',): {
            'inclusive_minimum': 0,
        },
        ('min_memory',): {
            'inclusive_minimum': 0,
        },
        ('feedback_size',): {
            'inclusive_minimum': 1,
        },
        ('stream_row_limit',): {
            'inclusive_minimum': -1,
        },
        ('num_input_streams',): {
            'inclusive_minimum': 1,
        },
        ('commit_size',): {
            'inclusive_minimum': 1,
        },
        ('num_output_threads_per_stream',): {
            'inclusive_minimum': 1,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'name': (str,),  # noqa: E501
            'rule_set_id': (str,),  # noqa: E501
            'type': (str,),  # noqa: E501
            'description': (str,),  # noqa: E501
            'discovery_policy_id': (str,),  # noqa: E501
            'max_memory': (int,),  # noqa: E501
            'min_memory': (int,),  # noqa: E501
            'feedback_size': (int,),  # noqa: E501
            'stream_row_limit': (int,),  # noqa: E501
            'num_input_streams': (int,),  # noqa: E501
            'fail_immediately': (bool,),  # noqa: E501
            'batch_update': (bool,),  # noqa: E501
            'commit_size': (int,),  # noqa: E501
            'num_output_threads_per_stream': (int,),  # noqa: E501
            'make_current_account_owner': (bool,),  # noqa: E501
            'is_multi_tenant': (bool,),  # noqa: E501
            'on_the_fly_source_connector_id': (str, none_type,),  # noqa: E501
            'reset_profiling_assignments': (bool,),  # noqa: E501
            'multiple_profiler_check': (bool,),  # noqa: E501
            'truncate_tables': (bool,),  # noqa: E501
            'drop_indexes': (bool,),  # noqa: E501
            'pre_script': (ComplianceJobScript,),  # noqa: E501
            'post_script': (ComplianceJobScript,),  # noqa: E501
            'enabled_tasks': ([str],),  # noqa: E501
            'tags': ([Tag],),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'name': 'name',  # noqa: E501
        'rule_set_id': 'rule_set_id',  # noqa: E501
        'type': 'type',  # noqa: E501
        'description': 'description',  # noqa: E501
        'discovery_policy_id': 'discovery_policy_id',  # noqa: E501
        'max_memory': 'max_memory',  # noqa: E501
        'min_memory': 'min_memory',  # noqa: E501
        'feedback_size': 'feedback_size',  # noqa: E501
        'stream_row_limit': 'stream_row_limit',  # noqa: E501
        'num_input_streams': 'num_input_streams',  # noqa: E501
        'fail_immediately': 'fail_immediately',  # noqa: E501
        'batch_update': 'batch_update',  # noqa: E501
        'commit_size': 'commit_size',  # noqa: E501
        'num_output_threads_per_stream': 'num_output_threads_per_stream',  # noqa: E501
        'make_current_account_owner': 'make_current_account_owner',  # noqa: E501
        'is_multi_tenant': 'is_multi_tenant',  # noqa: E501
        'on_the_fly_source_connector_id': 'on_the_fly_source_connector_id',  # noqa: E501
        'reset_profiling_assignments': 'reset_profiling_assignments',  # noqa: E501
        'multiple_profiler_check': 'multiple_profiler_check',  # noqa: E501
        'truncate_tables': 'truncate_tables',  # noqa: E501
        'drop_indexes': 'drop_indexes',  # noqa: E501
        'pre_script': 'pre_script',  # noqa: E501
        'post_script': 'post_script',  # noqa: E501
        'enabled_tasks': 'enabled_tasks',  # noqa: E501
        'tags': 'tags',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, name, rule_set_id, type, *args, **kwargs):  # noqa: E501
        """CreateComplianceJobRequest - a model defined in OpenAPI

        Args:
            name (str): The name of this compliance job.
            rule_set_id (str): The ID of the Rule Set used by this compliance job.
            type (str): The type of compliance job.

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            description (str): A description of the compliance job.. [optional]  # noqa: E501
            discovery_policy_id (str): The ID of the discovery policy to use for this compliance job. This is only applicable for DISCOVERY jobs.. [optional]  # noqa: E501
            max_memory (int): The maximum amount of memory, in MB, that the compliance job can consume during execution. A value of 0 or omitting this field uses the default max memory set in application settings.. [optional]  # noqa: E501
            min_memory (int): The minimum amount of memory, in MB, that the compliance job can consume during execution. Omitting this field uses the default min memory set in application settings.. [optional]  # noqa: E501
            feedback_size (int): The granularity with which the system provides updates on the progress of the compliance job. For instance, a feedback size of 50000 results in log updates whenever 50000 rows are processed during the masking phase.. [optional] if omitted the server will use the default value of 50000  # noqa: E501
            stream_row_limit (int): This value constrains the total number of rows that may enter the job for each masking stream. A value of 0 means unlimited. A value of -1 selects the default value. The minimum explicit value allowed is 20.. [optional]  # noqa: E501
            num_input_streams (int): This field controls the amount of parallelism that the masking job uses to extract out the data to be masked. For instance, when masking a database, specifying 5 input streams results in the compliance job reading up to 5 database tables in parallel and then masking those 5 streams of data in parallel. The higher the value of this field, the more potential parallelism there will be in the job, but the masking job will consume more memory. If the number of input streams exceeds the number of units being masked (e.g. tables or files), then the excess streams will do nothing.. [optional] if omitted the server will use the default value of 1  # noqa: E501
            fail_immediately (bool): Whether to fail immediately or delay failure until job completion when a masking algorithm fails to mask its data.. [optional] if omitted the server will use the default value of False  # noqa: E501
            batch_update (bool): Whether the database load phase to output the masked data will be performed in batches. The size of the batches is determined by the field 'commit_size'.. [optional] if omitted the server will use the default value of True  # noqa: E501
            commit_size (int): The size of the database commits when performing batch updates. Omitting this field uses the default commit size set in application settings.. [optional]  # noqa: E501
            num_output_threads_per_stream (int): The amount of parallelism, per input stream, that the job uses to load back the masked data. For example, specifying 4 output threads per stream with 5 input streams results in a total of 20 output threads for the whole job.. [optional] if omitted the server will use the default value of 1  # noqa: E501
            make_current_account_owner (bool): Whether the account creating this compliance job should be configured as its owner.. [optional] if omitted the server will use the default value of True  # noqa: E501
            is_multi_tenant (bool): If true, this job must be executed using a connector that is different from the underlying connector associated with its ruleset.. [optional] if omitted the server will use the default value of False  # noqa: E501
            on_the_fly_source_connector_id (str, none_type): The ID of the OTF source connector for this job.. [optional]  # noqa: E501
            reset_profiling_assignments (bool): Determines whether the ruleset assignments for the previous profiling execution need to be cleared before this job gets executed.. [optional]  # noqa: E501
            multiple_profiler_check (bool): When enabled, assigns a default algorithm if multiple classifiers match across different data classes above the threshold.. [optional]  # noqa: E501
            truncate_tables (bool): Whether to truncate target database tables before loading masked data. Only applies to database on-the-fly masking jobs.. [optional] if omitted the server will use the default value of False  # noqa: E501
            drop_indexes (bool): Whether to temporarily drop indexes prior to masking. This only applies to MySQL/MariaDB masking jobs. Other platforms should use enabled_tasks.. [optional] if omitted the server will use the default value of False  # noqa: E501
            pre_script (ComplianceJobScript): [optional]  # noqa: E501
            post_script (ComplianceJobScript): [optional]  # noqa: E501
            enabled_tasks ([str]): Tasks to perform before/after a job from a set of available driver support tasks as indicated by the target rule-set's connector.. [optional]  # noqa: E501
            tags ([Tag]): The tags to set on the compliance job.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.name = name
        self.rule_set_id = rule_set_id
        self.type = type
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, name, rule_set_id, type, *args, **kwargs):  # noqa: E501
        """CreateComplianceJobRequest - a model defined in OpenAPI

        Args:
            name (str): The name of this compliance job.
            rule_set_id (str): The ID of the Rule Set used by this compliance job.
            type (str): The type of compliance job.

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            description (str): A description of the compliance job.. [optional]  # noqa: E501
            discovery_policy_id (str): The ID of the discovery policy to use for this compliance job. This is only applicable for DISCOVERY jobs.. [optional]  # noqa: E501
            max_memory (int): The maximum amount of memory, in MB, that the compliance job can consume during execution. A value of 0 or omitting this field uses the default max memory set in application settings.. [optional]  # noqa: E501
            min_memory (int): The minimum amount of memory, in MB, that the compliance job can consume during execution. Omitting this field uses the default min memory set in application settings.. [optional]  # noqa: E501
            feedback_size (int): The granularity with which the system provides updates on the progress of the compliance job. For instance, a feedback size of 50000 results in log updates whenever 50000 rows are processed during the masking phase.. [optional] if omitted the server will use the default value of 50000  # noqa: E501
            stream_row_limit (int): This value constrains the total number of rows that may enter the job for each masking stream. A value of 0 means unlimited. A value of -1 selects the default value. The minimum explicit value allowed is 20.. [optional]  # noqa: E501
            num_input_streams (int): This field controls the amount of parallelism that the masking job uses to extract out the data to be masked. For instance, when masking a database, specifying 5 input streams results in the compliance job reading up to 5 database tables in parallel and then masking those 5 streams of data in parallel. The higher the value of this field, the more potential parallelism there will be in the job, but the masking job will consume more memory. If the number of input streams exceeds the number of units being masked (e.g. tables or files), then the excess streams will do nothing.. [optional] if omitted the server will use the default value of 1  # noqa: E501
            fail_immediately (bool): Whether to fail immediately or delay failure until job completion when a masking algorithm fails to mask its data.. [optional] if omitted the server will use the default value of False  # noqa: E501
            batch_update (bool): Whether the database load phase to output the masked data will be performed in batches. The size of the batches is determined by the field 'commit_size'.. [optional] if omitted the server will use the default value of True  # noqa: E501
            commit_size (int): The size of the database commits when performing batch updates. Omitting this field uses the default commit size set in application settings.. [optional]  # noqa: E501
            num_output_threads_per_stream (int): The amount of parallelism, per input stream, that the job uses to load back the masked data. For example, specifying 4 output threads per stream with 5 input streams results in a total of 20 output threads for the whole job.. [optional] if omitted the server will use the default value of 1  # noqa: E501
            make_current_account_owner (bool): Whether the account creating this compliance job should be configured as its owner.. [optional] if omitted the server will use the default value of True  # noqa: E501
            is_multi_tenant (bool): If true, this job must be executed using a connector that is different from the underlying connector associated with its ruleset.. [optional] if omitted the server will use the default value of False  # noqa: E501
            on_the_fly_source_connector_id (str, none_type): The ID of the OTF source connector for this job.. [optional]  # noqa: E501
            reset_profiling_assignments (bool): Determines whether the ruleset assignments for the previous profiling execution need to be cleared before this job gets executed.. [optional]  # noqa: E501
            multiple_profiler_check (bool): When enabled, assigns a default algorithm if multiple classifiers match across different data classes above the threshold.. [optional]  # noqa: E501
            truncate_tables (bool): Whether to truncate target database tables before loading masked data. Only applies to database on-the-fly masking jobs.. [optional] if omitted the server will use the default value of False  # noqa: E501
            drop_indexes (bool): Whether to temporarily drop indexes prior to masking. This only applies to MySQL/MariaDB masking jobs. Other platforms should use enabled_tasks.. [optional] if omitted the server will use the default value of False  # noqa: E501
            pre_script (ComplianceJobScript): [optional]  # noqa: E501
            post_script (ComplianceJobScript): [optional]  # noqa: E501
            enabled_tasks ([str]): Tasks to perform before/after a job from a set of available driver support tasks as indicated by the target rule-set's connector.. [optional]  # noqa: E501
            tags ([Tag]): The tags to set on the compliance job.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.name = name
        self.rule_set_id = rule_set_id
        self.type = type
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.add_engine_to_hyperscale_response import AddEngineToHyperscaleResponse
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.engine_id_body import EngineIdBody
from delphix.api.gateway.model.hyperscale_instance import HyperscaleInstance
from delphix.api.gateway.model.hyperscale_instance_registration_parameter import HyperscaleInstanceRegistrationParameter
from delphix.api.gateway.model.hyperscale_instance_update_params import HyperscaleInstanceUpdateParams
from delphix.api.gateway.model.list_hyperscale_instances_response import ListHyperscaleInstancesResponse
from delphix.api.gateway.model.remove_engine_from_hyperscale_response import RemoveEngineFromHyperscaleResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_hyperscale_instances_response import SearchHyperscaleInstancesResponse
from delphix.api.gateway.model.sync_engines_hyperscale_parameters import SyncEnginesHyperscaleParameters
from delphix.api.gateway.model.sync_engines_hyperscale_response import SyncEnginesHyperscaleResponse
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
from delphix.api.gateway.model.unregister_hyperscale_instance_response import UnregisterHyperscaleInstanceResponse


class HyperscaleInstanceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __add_engine_to_hyperscale_instance(
            self,
            hyperscale_instance_id,
            engine_id_body,
            **kwargs
        ):
            """Add an engine to a Hyperscale Instance.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.add_engine_to_hyperscale_instance(hyperscale_instance_id, engine_id_body, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_instance_id (str): The ID of hyperscale instance.
                engine_id_body (EngineIdBody): Body containing the ID of the registered engine.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                AddEngineToHyperscaleResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_instance_id'] = \
                hyperscale_instance_id
            kwargs['engine_id_body'] = \
                engine_id_body
            return self.call_with_http_info(**kwargs)

        self.add_engine_to_hyperscale_instance = _Endpoint(
            settings={
                'response_type': (AddEngineToHyperscaleResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances/{hyperscaleInstanceId}/add-engine',
                'operation_id': 'add_engine_to_hyperscale_instance',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_instance_id',
                    'engine_id_body',
                ],
                'required': [
                    'hyperscale_instance_id',
                    'engine_id_body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_instance_id':
                        (str,),
                    'engine_id_body':
                        (EngineIdBody,),
                },
                'attribute_map': {
                    'hyperscale_instance_id': 'hyperscaleInstanceId',
                },
                'location_map': {
                    'hyperscale_instance_id': 'path',
                    'engine_id_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__add_engine_to_hyperscale_instance
        )

        def __create_hyperscale_instance_tags(
            self,
            hyperscale_instance_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a Hyperscale Instance.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_hyperscale_instance_tags(hyperscale_instance_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_instance_id (str): The ID of hyperscale instance.
                tags_request (TagsRequest): Tags information for Hyperscale Instance.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_instance_id'] = \
                hyperscale_instance_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_hyperscale_instance_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances/{hyperscaleInstanceId}/tags',
                'operation_id': 'create_hyperscale_instance_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_instance_id',
                    'tags_request',
                ],
                'required': [
                    'hyperscale_instance_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_instance_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'hyperscale_instance_id': 'hyperscaleInstanceId',
                },
                'location_map': {
                    'hyperscale_instance_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_hyperscale_instance_tags
        )

        def __delete_hyperscale_instance_tags(
            self,
            hyperscale_instance_id,
            **kwargs
        ):
            """Delete tags for a Hyperscale Instance.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_hyperscale_instance_tags(hyperscale_instance_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_instance_id (str): The ID of hyperscale instance.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_instance_id'] = \
                hyperscale_instance_id
            return self.call_with_http_info(**kwargs)

        self.delete_hyperscale_instance_tags = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances/{hyperscaleInstanceId}/tags/delete',
                'operation_id': 'delete_hyperscale_instance_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_instance_id',
                    'delete_tag',
                ],
                'required': [
                    'hyperscale_instance_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_instance_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'hyperscale_instance_id': 'hyperscaleInstanceId',
                },
                'location_map': {
                    'hyperscale_instance_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_hyperscale_instance_tags
        )

        def __get_hyperscale_instance_by_id(
            self,
            hyperscale_instance_id,
            **kwargs
        ):
            """Returns a Hyperscale Instance by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_instance_by_id(hyperscale_instance_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_instance_id (str): The ID of hyperscale instance.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                HyperscaleInstance
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_instance_id'] = \
                hyperscale_instance_id
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_instance_by_id = _Endpoint(
            settings={
                'response_type': (HyperscaleInstance,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances/{hyperscaleInstanceId}',
                'operation_id': 'get_hyperscale_instance_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_instance_id',
                ],
                'required': [
                    'hyperscale_instance_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_instance_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_instance_id': 'hyperscaleInstanceId',
                },
                'location_map': {
                    'hyperscale_instance_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_instance_by_id
        )

        def __get_hyperscale_instance_tags(
            self,
            hyperscale_instance_id,
            **kwargs
        ):
            """Get tags for a Hyperscale Instance.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_instance_tags(hyperscale_instance_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_instance_id (str): The ID of hyperscale instance.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_instance_id'] = \
                hyperscale_instance_id
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_instance_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances/{hyperscaleInstanceId}/tags',
                'operation_id': 'get_hyperscale_instance_tags',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_instance_id',
                ],
                'required': [
                    'hyperscale_instance_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_instance_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_instance_id': 'hyperscaleInstanceId',
                },
                'location_map': {
                    'hyperscale_instance_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_instance_tags
        )

        def __get_hyperscale_instances(
            self,
            **kwargs
        ):
            """Returns a list of Hyperscale instances.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_instances(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListHyperscaleInstancesResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_instances = _Endpoint(
            settings={
                'response_type': (ListHyperscaleInstancesResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances',
                'operation_id': 'get_hyperscale_instances',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "HOSTNAME": "hostname",
                        "-HOSTNAME": "-hostname",
                        "CREATION_DATE": "creation_date",
                        "-CREATION_DATE": "-creation_date",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "DATA_TYPE": "data_type",
                        "-DATA_TYPE": "-data_type",
                        "CONNECTION_STATUS": "connection_status",
                        "-CONNECTION_STATUS": "-connection_status",
                        "CONNECTION_STATUS_DETAILS": "connection_status_details",
                        "-CONNECTION_STATUS_DETAILS": "-connection_status_details"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_instances
        )

        def __register_hyperscale_instance(
            self,
            hyperscale_instance_registration_parameter,
            **kwargs
        ):
            """Register a Hyperscale instance  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.register_hyperscale_instance(hyperscale_instance_registration_parameter, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_instance_registration_parameter (HyperscaleInstanceRegistrationParameter): The parameters to register a Hyperscale instance.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                HyperscaleInstance
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_instance_registration_parameter'] = \
                hyperscale_instance_registration_parameter
            return self.call_with_http_info(**kwargs)

        self.register_hyperscale_instance = _Endpoint(
            settings={
                'response_type': (HyperscaleInstance,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances',
                'operation_id': 'register_hyperscale_instance',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_instance_registration_parameter',
                ],
                'required': [
                    'hyperscale_instance_registration_parameter',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_instance_registration_parameter':
                        (HyperscaleInstanceRegistrationParameter,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'hyperscale_instance_registration_parameter': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__register_hyperscale_instance
        )

        def __remove_engine_from_hyperscale_instance(
            self,
            hyperscale_instance_id,
            engine_id_body,
            **kwargs
        ):
            """Remove an engine from a Hyperscale Instance.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.remove_engine_from_hyperscale_instance(hyperscale_instance_id, engine_id_body, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_instance_id (str): The ID of hyperscale instance.
                engine_id_body (EngineIdBody): Body containing the ID of the registered engine.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RemoveEngineFromHyperscaleResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_instance_id'] = \
                hyperscale_instance_id
            kwargs['engine_id_body'] = \
                engine_id_body
            return self.call_with_http_info(**kwargs)

        self.remove_engine_from_hyperscale_instance = _Endpoint(
            settings={
                'response_type': (RemoveEngineFromHyperscaleResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances/{hyperscaleInstanceId}/remove-engine',
                'operation_id': 'remove_engine_from_hyperscale_instance',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_instance_id',
                    'engine_id_body',
                ],
                'required': [
                    'hyperscale_instance_id',
                    'engine_id_body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_instance_id':
                        (str,),
                    'engine_id_body':
                        (EngineIdBody,),
                },
                'attribute_map': {
                    'hyperscale_instance_id': 'hyperscaleInstanceId',
                },
                'location_map': {
                    'hyperscale_instance_id': 'path',
                    'engine_id_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__remove_engine_from_hyperscale_instance
        )

        def __search_hyperscale_instances(
            self,
            **kwargs
        ):
            """Search for Hyperscale instances.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_hyperscale_instances(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchHyperscaleInstancesResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_hyperscale_instances = _Endpoint(
            settings={
                'response_type': (SearchHyperscaleInstancesResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances/search',
                'operation_id': 'search_hyperscale_instances',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "HOSTNAME": "hostname",
                        "-HOSTNAME": "-hostname",
                        "CREATION_DATE": "creation_date",
                        "-CREATION_DATE": "-creation_date",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "DATA_TYPE": "data_type",
                        "-DATA_TYPE": "-data_type",
                        "CONNECTION_STATUS": "connection_status",
                        "-CONNECTION_STATUS": "-connection_status",
                        "CONNECTION_STATUS_DETAILS": "connection_status_details",
                        "-CONNECTION_STATUS_DETAILS": "-connection_status_details"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_hyperscale_instances
        )

        def __sync_engines_hyperscale_instance(
            self,
            hyperscale_instance_id,
            **kwargs
        ):
            """Sync the global object from a source engine to engines on a Hyperscale Instance.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.sync_engines_hyperscale_instance(hyperscale_instance_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_instance_id (str): The ID of hyperscale instance.

            Keyword Args:
                sync_engines_hyperscale_parameters (SyncEnginesHyperscaleParameters): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SyncEnginesHyperscaleResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_instance_id'] = \
                hyperscale_instance_id
            return self.call_with_http_info(**kwargs)

        self.sync_engines_hyperscale_instance = _Endpoint(
            settings={
                'response_type': (SyncEnginesHyperscaleResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances/{hyperscaleInstanceId}/sync-engines',
                'operation_id': 'sync_engines_hyperscale_instance',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_instance_id',
                    'sync_engines_hyperscale_parameters',
                ],
                'required': [
                    'hyperscale_instance_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_instance_id':
                        (str,),
                    'sync_engines_hyperscale_parameters':
                        (SyncEnginesHyperscaleParameters,),
                },
                'attribute_map': {
                    'hyperscale_instance_id': 'hyperscaleInstanceId',
                },
                'location_map': {
                    'hyperscale_instance_id': 'path',
                    'sync_engines_hyperscale_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__sync_engines_hyperscale_instance
        )

        def __unregister_hyperscale_instance(
            self,
            hyperscale_instance_id,
            **kwargs
        ):
            """Unregister a Hyperscale Instance.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.unregister_hyperscale_instance(hyperscale_instance_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_instance_id (str): The ID of hyperscale instance.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UnregisterHyperscaleInstanceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_instance_id'] = \
                hyperscale_instance_id
            return self.call_with_http_info(**kwargs)

        self.unregister_hyperscale_instance = _Endpoint(
            settings={
                'response_type': (UnregisterHyperscaleInstanceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances/{hyperscaleInstanceId}',
                'operation_id': 'unregister_hyperscale_instance',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_instance_id',
                ],
                'required': [
                    'hyperscale_instance_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_instance_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_instance_id': 'hyperscaleInstanceId',
                },
                'location_map': {
                    'hyperscale_instance_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__unregister_hyperscale_instance
        )

        def __update_hyperscale_instance(
            self,
            hyperscale_instance_id,
            hyperscale_instance_update_params,
            **kwargs
        ):
            """Update an Hyperscale Instance  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_hyperscale_instance(hyperscale_instance_id, hyperscale_instance_update_params, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_instance_id (str): The ID of hyperscale instance.
                hyperscale_instance_update_params (HyperscaleInstanceUpdateParams): Update parameters for a hyperscale instance.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                HyperscaleInstance
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_instance_id'] = \
                hyperscale_instance_id
            kwargs['hyperscale_instance_update_params'] = \
                hyperscale_instance_update_params
            return self.call_with_http_info(**kwargs)

        self.update_hyperscale_instance = _Endpoint(
            settings={
                'response_type': (HyperscaleInstance,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-instances/{hyperscaleInstanceId}',
                'operation_id': 'update_hyperscale_instance',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_instance_id',
                    'hyperscale_instance_update_params',
                ],
                'required': [
                    'hyperscale_instance_id',
                    'hyperscale_instance_update_params',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_instance_id':
                        (str,),
                    'hyperscale_instance_update_params':
                        (HyperscaleInstanceUpdateParams,),
                },
                'attribute_map': {
                    'hyperscale_instance_id': 'hyperscaleInstanceId',
                },
                'location_map': {
                    'hyperscale_instance_id': 'path',
                    'hyperscale_instance_update_params': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_hyperscale_instance
        )



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.dct_product_telemetry_bundle_administration_info import DCTProductTelemetryBundleAdministrationInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_api_telemetry import DctProductTelemetryBundleApiTelemetry
from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_job import DctProductTelemetryBundleComplianceJob
from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_node import DctProductTelemetryBundleComplianceNode
from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_object_counts import DctProductTelemetryBundleComplianceObjectCounts
from delphix.api.gateway.model.dct_product_telemetry_bundle_connector import DctProductTelemetryBundleConnector
from delphix.api.gateway.model.dct_product_telemetry_bundle_continuous_data_engine_storage import DctProductTelemetryBundleContinuousDataEngineStorage
from delphix.api.gateway.model.dct_product_telemetry_bundle_d_source_info import DCTProductTelemetryBundleDSourceInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_data_connection_storage import DctProductTelemetryBundleDataConnectionStorage
from delphix.api.gateway.model.dct_product_telemetry_bundle_environment_info import DCTProductTelemetryBundleEnvironmentInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_execution import DctProductTelemetryBundleExecution
from delphix.api.gateway.model.dct_product_telemetry_bundle_hyperscale_orchestrator import DctProductTelemetryBundleHyperscaleOrchestrator
from delphix.api.gateway.model.dct_product_telemetry_bundle_job_orchestrator import DctProductTelemetryBundleJobOrchestrator
from delphix.api.gateway.model.dct_product_telemetry_bundle_license_info import DctProductTelemetryBundleLicenseInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_object_counts import DCTProductTelemetryBundleObjectCounts
from delphix.api.gateway.model.dct_product_telemetry_bundle_product_info import DctProductTelemetryBundleProductInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_registered_engine import DctProductTelemetryBundleRegisteredEngine
from delphix.api.gateway.model.dct_product_telemetry_bundle_rule_set import DctProductTelemetryBundleRuleSet
from delphix.api.gateway.model.dct_product_telemetry_bundle_vdb_info import DCTProductTelemetryBundleVDBInfo
from delphix.api.gateway.model.dct_product_telemetry_data_connection import DctProductTelemetryDataConnection
globals()['DCTProductTelemetryBundleAdministrationInfo'] = DCTProductTelemetryBundleAdministrationInfo
globals()['DCTProductTelemetryBundleDSourceInfo'] = DCTProductTelemetryBundleDSourceInfo
globals()['DCTProductTelemetryBundleEnvironmentInfo'] = DCTProductTelemetryBundleEnvironmentInfo
globals()['DCTProductTelemetryBundleObjectCounts'] = DCTProductTelemetryBundleObjectCounts
globals()['DCTProductTelemetryBundleVDBInfo'] = DCTProductTelemetryBundleVDBInfo
globals()['DctProductTelemetryBundleApiTelemetry'] = DctProductTelemetryBundleApiTelemetry
globals()['DctProductTelemetryBundleComplianceJob'] = DctProductTelemetryBundleComplianceJob
globals()['DctProductTelemetryBundleComplianceNode'] = DctProductTelemetryBundleComplianceNode
globals()['DctProductTelemetryBundleComplianceObjectCounts'] = DctProductTelemetryBundleComplianceObjectCounts
globals()['DctProductTelemetryBundleConnector'] = DctProductTelemetryBundleConnector
globals()['DctProductTelemetryBundleContinuousDataEngineStorage'] = DctProductTelemetryBundleContinuousDataEngineStorage
globals()['DctProductTelemetryBundleDataConnectionStorage'] = DctProductTelemetryBundleDataConnectionStorage
globals()['DctProductTelemetryBundleExecution'] = DctProductTelemetryBundleExecution
globals()['DctProductTelemetryBundleHyperscaleOrchestrator'] = DctProductTelemetryBundleHyperscaleOrchestrator
globals()['DctProductTelemetryBundleJobOrchestrator'] = DctProductTelemetryBundleJobOrchestrator
globals()['DctProductTelemetryBundleLicenseInfo'] = DctProductTelemetryBundleLicenseInfo
globals()['DctProductTelemetryBundleProductInfo'] = DctProductTelemetryBundleProductInfo
globals()['DctProductTelemetryBundleRegisteredEngine'] = DctProductTelemetryBundleRegisteredEngine
globals()['DctProductTelemetryBundleRuleSet'] = DctProductTelemetryBundleRuleSet
globals()['DctProductTelemetryDataConnection'] = DctProductTelemetryDataConnection
from delphix.api.gateway.model.dct_product_telemetry_bundle import DctProductTelemetryBundle


class TestDctProductTelemetryBundle(unittest.TestCase):
    """DctProductTelemetryBundle unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDctProductTelemetryBundle(self):
        """Test DctProductTelemetryBundle"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DctProductTelemetryBundle()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.paa_s_plugins_api import PaaSPluginsApi  # noqa: E501


class TestPaaSPluginsApi(unittest.TestCase):
    """PaaSPluginsApi unit test stubs"""

    def setUp(self):
        self.api = PaaSPluginsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_paas_plugin_tags(self):
        """Test case for create_paas_plugin_tags

        Create tags for a PaaS plugin.  # noqa: E501
        """
        pass

    def test_delete_paas_plugin_tags(self):
        """Test case for delete_paas_plugin_tags

        Delete tags for a PaaS Plugin.  # noqa: E501
        """
        pass

    def test_get_paas_plugin_tags(self):
        """Test case for get_paas_plugin_tags

        Get tags for a PaaS Plugin.  # noqa: E501
        """
        pass

    def test_get_paas_plugins(self):
        """Test case for get_paas_plugins

        List all registered PaaS plugins.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.jobs_api import JobsApi  # noqa: E501


class TestJobsApi(unittest.TestCase):
    """JobsApi unit test stubs"""

    def setUp(self):
        self.api = JobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abandon_job(self):
        """Test case for abandon_job

        Abandons a job.  # noqa: E501
        """
        pass

    def test_create_job_tags(self):
        """Test case for create_job_tags

        Create tags for a Job.  # noqa: E501
        """
        pass

    def test_delete_job_tag(self):
        """Test case for delete_job_tag

        Delete tags for a Job.  # noqa: E501
        """
        pass

    def test_get_job_by_id(self):
        """Test case for get_job_by_id

        Returns a job by ID.  # noqa: E501
        """
        pass

    def test_get_job_result(self):
        """Test case for get_job_result

        Get job result.  # noqa: E501
        """
        pass

    def test_get_job_tags(self):
        """Test case for get_job_tags

        Get tags for a Job.  # noqa: E501
        """
        pass

    def test_get_jobs(self):
        """Test case for get_jobs

        List all jobs.  # noqa: E501
        """
        pass

    def test_search_jobs(self):
        """Test case for search_jobs

        Search for jobs.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.policy_target_object import PolicyTargetObject
from delphix.api.gateway.model.policy_type import PolicyType
from delphix.api.gateway.model.provision_source import ProvisionSource
from delphix.api.gateway.model.tag import Tag
from delphix.api.gateway.model.virtualization_schedule import VirtualizationSchedule
globals()['PolicyTargetObject'] = PolicyTargetObject
globals()['PolicyType'] = PolicyType
globals()['ProvisionSource'] = ProvisionSource
globals()['Tag'] = Tag
globals()['VirtualizationSchedule'] = VirtualizationSchedule
from delphix.api.gateway.model.create_virtualization_policy_parameters import CreateVirtualizationPolicyParameters


class TestCreateVirtualizationPolicyParameters(unittest.TestCase):
    """CreateVirtualizationPolicyParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateVirtualizationPolicyParameters(self):
        """Test CreateVirtualizationPolicyParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateVirtualizationPolicyParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.ai_generate_api import AiGenerateApi  # noqa: E501


class TestAiGenerateApi(unittest.TestCase):
    """AiGenerateApi unit test stubs"""

    def setUp(self):
        self.api = AiGenerateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_download_generate_values(self):
        """Test case for download_generate_values

        Download all values generated by the operation in the specified format  # noqa: E501
        """
        pass

    def test_generate_data(self):
        """Test case for generate_data

        Initiate an operation that creates a list of data values using generative AI  # noqa: E501
        """
        pass

    def test_get_all_generate_operations(self):
        """Test case for get_all_generate_operations

        Get the details of all data generate operations  # noqa: E501
        """
        pass

    def test_get_generate_operation(self):
        """Test case for get_generate_operation

        Get the details of a data generate operation  # noqa: E501
        """
        pass

    def test_get_generate_values(self):
        """Test case for get_generate_values

        Get all values generated by a data generate operation  # noqa: E501
        """
        pass

    def test_search_all_generate_operations(self):
        """Test case for search_all_generate_operations

        Search for the details of data generate operations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.source_operation import SourceOperation
    globals()['SourceOperation'] = SourceOperation


class OracleDSourceLinkSourceParametersAllOf(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('log_sync_mode',): {
            'ARCHIVE_ONLY_MODE': "ARCHIVE_ONLY_MODE",
            'ARCHIVE_REDO_MODE': "ARCHIVE_REDO_MODE",
            'UNDEFINED': "UNDEFINED",
        },
    }

    validations = {
        ('external_file_path',): {
            'max_length': 1024,
            'min_length': 1,
        },
        ('environment_user_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('rman_channels',): {
            'inclusive_maximum': 32,
            'inclusive_minimum': 1,
        },
        ('files_per_set',): {
            'inclusive_maximum': 64,
            'inclusive_minimum': 1,
        },
        ('non_sys_username',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_password',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_vault_username',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_vault',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_hashicorp_vault_engine',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_hashicorp_vault_secret_path',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_hashicorp_vault_username_key',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_hashicorp_vault_secret_key',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_azure_vault_name',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_azure_vault_username_key',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_azure_vault_secret_key',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('non_sys_cyberark_vault_query_string',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_username',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_password',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_vault_username',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_vault',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_hashicorp_vault_engine',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_hashicorp_vault_secret_path',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_hashicorp_vault_username_key',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_hashicorp_vault_secret_key',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_azure_vault_name',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_azure_vault_username_key',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_azure_vault_secret_key',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('fallback_cyberark_vault_query_string',): {
            'max_length': 256,
            'min_length': 1,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'external_file_path': (str,),  # noqa: E501
            'environment_user_id': (str,),  # noqa: E501
            'backup_level_enabled': (bool,),  # noqa: E501
            'rman_channels': (int,),  # noqa: E501
            'files_per_set': (int,),  # noqa: E501
            'check_logical': (bool,),  # noqa: E501
            'encrypted_linking_enabled': (bool,),  # noqa: E501
            'compressed_linking_enabled': (bool,),  # noqa: E501
            'bandwidth_limit': (int,),  # noqa: E501
            'number_of_connections': (int,),  # noqa: E501
            'diagnose_no_logging_faults': (bool,),  # noqa: E501
            'pre_provisioning_enabled': (bool,),  # noqa: E501
            'link_now': (bool,),  # noqa: E501
            'force_full_backup': (bool,),  # noqa: E501
            'double_sync': (bool,),  # noqa: E501
            'rman_rate_in_mb': (int,),  # noqa: E501
            'skip_space_check': (bool,),  # noqa: E501
            'do_not_resume': (bool,),  # noqa: E501
            'files_for_full_backup': ([int],),  # noqa: E501
            'log_sync_mode': (str,),  # noqa: E501
            'log_sync_interval': (int,),  # noqa: E501
            'non_sys_username': (str,),  # noqa: E501
            'non_sys_password': (str,),  # noqa: E501
            'non_sys_vault_username': (str,),  # noqa: E501
            'non_sys_vault': (str,),  # noqa: E501
            'non_sys_hashicorp_vault_engine': (str,),  # noqa: E501
            'non_sys_hashicorp_vault_secret_path': (str,),  # noqa: E501
            'non_sys_hashicorp_vault_username_key': (str,),  # noqa: E501
            'non_sys_hashicorp_vault_secret_key': (str,),  # noqa: E501
            'non_sys_azure_vault_name': (str,),  # noqa: E501
            'non_sys_azure_vault_username_key': (str,),  # noqa: E501
            'non_sys_azure_vault_secret_key': (str,),  # noqa: E501
            'non_sys_cyberark_vault_query_string': (str,),  # noqa: E501
            'fallback_username': (str,),  # noqa: E501
            'fallback_password': (str,),  # noqa: E501
            'fallback_vault_username': (str,),  # noqa: E501
            'fallback_vault': (str,),  # noqa: E501
            'fallback_hashicorp_vault_engine': (str,),  # noqa: E501
            'fallback_hashicorp_vault_secret_path': (str,),  # noqa: E501
            'fallback_hashicorp_vault_username_key': (str,),  # noqa: E501
            'fallback_hashicorp_vault_secret_key': (str,),  # noqa: E501
            'fallback_azure_vault_name': (str,),  # noqa: E501
            'fallback_azure_vault_username_key': (str,),  # noqa: E501
            'fallback_azure_vault_secret_key': (str,),  # noqa: E501
            'fallback_cyberark_vault_query_string': (str,),  # noqa: E501
            'ops_pre_log_sync': ([SourceOperation],),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'external_file_path': 'external_file_path',  # noqa: E501
        'environment_user_id': 'environment_user_id',  # noqa: E501
        'backup_level_enabled': 'backup_level_enabled',  # noqa: E501
        'rman_channels': 'rman_channels',  # noqa: E501
        'files_per_set': 'files_per_set',  # noqa: E501
        'check_logical': 'check_logical',  # noqa: E501
        'encrypted_linking_enabled': 'encrypted_linking_enabled',  # noqa: E501
        'compressed_linking_enabled': 'compressed_linking_enabled',  # noqa: E501
        'bandwidth_limit': 'bandwidth_limit',  # noqa: E501
        'number_of_connections': 'number_of_connections',  # noqa: E501
        'diagnose_no_logging_faults': 'diagnose_no_logging_faults',  # noqa: E501
        'pre_provisioning_enabled': 'pre_provisioning_enabled',  # noqa: E501
        'link_now': 'link_now',  # noqa: E501
        'force_full_backup': 'force_full_backup',  # noqa: E501
        'double_sync': 'double_sync',  # noqa: E501
        'rman_rate_in_mb': 'rman_rate_in_MB',  # noqa: E501
        'skip_space_check': 'skip_space_check',  # noqa: E501
        'do_not_resume': 'do_not_resume',  # noqa: E501
        'files_for_full_backup': 'files_for_full_backup',  # noqa: E501
        'log_sync_mode': 'log_sync_mode',  # noqa: E501
        'log_sync_interval': 'log_sync_interval',  # noqa: E501
        'non_sys_username': 'non_sys_username',  # noqa: E501
        'non_sys_password': 'non_sys_password',  # noqa: E501
        'non_sys_vault_username': 'non_sys_vault_username',  # noqa: E501
        'non_sys_vault': 'non_sys_vault',  # noqa: E501
        'non_sys_hashicorp_vault_engine': 'non_sys_hashicorp_vault_engine',  # noqa: E501
        'non_sys_hashicorp_vault_secret_path': 'non_sys_hashicorp_vault_secret_path',  # noqa: E501
        'non_sys_hashicorp_vault_username_key': 'non_sys_hashicorp_vault_username_key',  # noqa: E501
        'non_sys_hashicorp_vault_secret_key': 'non_sys_hashicorp_vault_secret_key',  # noqa: E501
        'non_sys_azure_vault_name': 'non_sys_azure_vault_name',  # noqa: E501
        'non_sys_azure_vault_username_key': 'non_sys_azure_vault_username_key',  # noqa: E501
        'non_sys_azure_vault_secret_key': 'non_sys_azure_vault_secret_key',  # noqa: E501
        'non_sys_cyberark_vault_query_string': 'non_sys_cyberark_vault_query_string',  # noqa: E501
        'fallback_username': 'fallback_username',  # noqa: E501
        'fallback_password': 'fallback_password',  # noqa: E501
        'fallback_vault_username': 'fallback_vault_username',  # noqa: E501
        'fallback_vault': 'fallback_vault',  # noqa: E501
        'fallback_hashicorp_vault_engine': 'fallback_hashicorp_vault_engine',  # noqa: E501
        'fallback_hashicorp_vault_secret_path': 'fallback_hashicorp_vault_secret_path',  # noqa: E501
        'fallback_hashicorp_vault_username_key': 'fallback_hashicorp_vault_username_key',  # noqa: E501
        'fallback_hashicorp_vault_secret_key': 'fallback_hashicorp_vault_secret_key',  # noqa: E501
        'fallback_azure_vault_name': 'fallback_azure_vault_name',  # noqa: E501
        'fallback_azure_vault_username_key': 'fallback_azure_vault_username_key',  # noqa: E501
        'fallback_azure_vault_secret_key': 'fallback_azure_vault_secret_key',  # noqa: E501
        'fallback_cyberark_vault_query_string': 'fallback_cyberark_vault_query_string',  # noqa: E501
        'ops_pre_log_sync': 'ops_pre_log_sync',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """OracleDSourceLinkSourceParametersAllOf - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            external_file_path (str): External file path.. [optional]  # noqa: E501
            environment_user_id (str): Id of the environment user to use for linking.. [optional]  # noqa: E501
            backup_level_enabled (bool): Boolean value indicates whether LEVEL-based incremental backups can be used on the source database.. [optional]  # noqa: E501
            rman_channels (int): Number of parallel channels to use.. [optional] if omitted the server will use the default value of 2  # noqa: E501
            files_per_set (int): Number of data files to include in each RMAN backup set.. [optional] if omitted the server will use the default value of 5  # noqa: E501
            check_logical (bool): True if extended block checking should be used for this linked database.. [optional] if omitted the server will use the default value of False  # noqa: E501
            encrypted_linking_enabled (bool): True if SnapSync data from the source should be retrieved through an encrypted connection. Enabling this feature can decrease the performance of SnapSync from the source but has no impact on the performance of VDBs created from the retrieved data.. [optional] if omitted the server will use the default value of False  # noqa: E501
            compressed_linking_enabled (bool): True if SnapSync data from the source should be compressed over the network. Enabling this feature will reduce network bandwidth consumption and may significantly improve throughput, especially over slow network.. [optional] if omitted the server will use the default value of True  # noqa: E501
            bandwidth_limit (int): Bandwidth limit (MB/s) for SnapSync and LogSync network traffic. A value of 0 means no limit.. [optional] if omitted the server will use the default value of 0  # noqa: E501
            number_of_connections (int): Total number of transport connections to use during SnapSync.. [optional] if omitted the server will use the default value of 1  # noqa: E501
            diagnose_no_logging_faults (bool): If true, NOLOGGING operations on this container are treated as faults and cannot be resolved manually.. [optional] if omitted the server will use the default value of True  # noqa: E501
            pre_provisioning_enabled (bool): If true, pre-provisioning will be performed after every sync.. [optional] if omitted the server will use the default value of False  # noqa: E501
            link_now (bool): True if initial load should be done immediately.. [optional] if omitted the server will use the default value of False  # noqa: E501
            force_full_backup (bool): Whether or not to take another full backup of the source database.. [optional] if omitted the server will use the default value of False  # noqa: E501
            double_sync (bool): True if two SnapSyncs should be performed in immediate succession to reduce the number of logs required to provision the snapshot. This may significantly reduce the time necessary to provision from a snapshot.. [optional] if omitted the server will use the default value of False  # noqa: E501
            rman_rate_in_mb (int): RMAN rate in megabytes to be used. This is the upper limit for bytes read so that RMAN does not consume excessive disk bandwidth and degrade online performance. (Oracle only) . [optional] if omitted the server will use the default value of 0  # noqa: E501
            skip_space_check (bool): Skip check that tests if there is enough space available to store the database in the Delphix Engine. The Delphix Engine estimates how much space a database will occupy after compression and prevents SnapSync if insufficient space is available. This safeguard can be overridden using this option. This may be useful when linking highly compressible databases.. [optional] if omitted the server will use the default value of False  # noqa: E501
            do_not_resume (bool): Indicates whether a fresh SnapSync must be started regardless if it was possible to resume the current SnapSync. If true, we will not resume but instead ignore previous progress and backup all datafiles even if already completed from previous failed SnapSync. This does not force a full backup, if an incremental was in progress this will start a new incremental snapshot.. [optional] if omitted the server will use the default value of False  # noqa: E501
            files_for_full_backup ([int]): List of datafiles to take a full backup of. This would be useful in situations where certain datafiles could not be backed up during previous SnapSync due to corruption or because they went offline.. [optional]  # noqa: E501
            log_sync_mode (str): LogSync operation mode for this database.. [optional] if omitted the server will use the default value of "UNDEFINED"  # noqa: E501
            log_sync_interval (int): Interval between LogSync requests, in seconds.. [optional] if omitted the server will use the default value of 5  # noqa: E501
            non_sys_username (str): Non-SYS database user to access this database. Only required for username-password auth (Single tenant only).. [optional]  # noqa: E501
            non_sys_password (str): Password for non sys user authentication (Single tenant only).. [optional]  # noqa: E501
            non_sys_vault_username (str): Delphix display name for the non sys vault user(Single tenant only).. [optional]  # noqa: E501
            non_sys_vault (str): The name or reference of the vault from which to read the database credentials (Single tenant only).. [optional]  # noqa: E501
            non_sys_hashicorp_vault_engine (str): Vault engine name where the credential is stored (Single tenant only).. [optional]  # noqa: E501
            non_sys_hashicorp_vault_secret_path (str): Path in the vault engine where the credential is stored (Single tenant only).. [optional]  # noqa: E501
            non_sys_hashicorp_vault_username_key (str): Hashicorp vault key for the username in the key-value store (Single tenant only).. [optional]  # noqa: E501
            non_sys_hashicorp_vault_secret_key (str): Hashicorp vault key for the password in the key-value store (Single tenant only).. [optional]  # noqa: E501
            non_sys_azure_vault_name (str): Azure key vault name (Single tenant only).. [optional]  # noqa: E501
            non_sys_azure_vault_username_key (str): Azure vault key for the username in the key-value store (Single tenant only).. [optional]  # noqa: E501
            non_sys_azure_vault_secret_key (str): Azure vault key for the password in the key-value store (Single tenant only).. [optional]  # noqa: E501
            non_sys_cyberark_vault_query_string (str): Query to find a credential in the CyberArk vault (Single tenant only).. [optional]  # noqa: E501
            fallback_username (str): The database fallback username. Optional if bequeath connections are enabled (to be used in case of bequeath connection failures). Only required for username-password auth.. [optional]  # noqa: E501
            fallback_password (str): Password for fallback username.. [optional]  # noqa: E501
            fallback_vault_username (str): Delphix display name for the fallback vault user.. [optional]  # noqa: E501
            fallback_vault (str): The name or reference of the vault from which to read the database credentials.. [optional]  # noqa: E501
            fallback_hashicorp_vault_engine (str): Vault engine name where the credential is stored.. [optional]  # noqa: E501
            fallback_hashicorp_vault_secret_path (str): Path in the vault engine where the credential is stored.. [optional]  # noqa: E501
            fallback_hashicorp_vault_username_key (str): Hashicorp vault key for the username in the key-value store.. [optional]  # noqa: E501
            fallback_hashicorp_vault_secret_key (str): Hashicorp vault key for the password in the key-value store.. [optional]  # noqa: E501
            fallback_azure_vault_name (str): Azure key vault name.. [optional]  # noqa: E501
            fallback_azure_vault_username_key (str): Azure vault key for the username in the key-value store.. [optional]  # noqa: E501
            fallback_azure_vault_secret_key (str): Azure vault key for the password in the key-value store.. [optional]  # noqa: E501
            fallback_cyberark_vault_query_string (str): Query to find a credential in the CyberArk vault.. [optional]  # noqa: E501
            ops_pre_log_sync ([SourceOperation]): Operations to perform after syncing a created dSource and before running the LogSync.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """OracleDSourceLinkSourceParametersAllOf - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            external_file_path (str): External file path.. [optional]  # noqa: E501
            environment_user_id (str): Id of the environment user to use for linking.. [optional]  # noqa: E501
            backup_level_enabled (bool): Boolean value indicates whether LEVEL-based incremental backups can be used on the source database.. [optional]  # noqa: E501
            rman_channels (int): Number of parallel channels to use.. [optional] if omitted the server will use the default value of 2  # noqa: E501
            files_per_set (int): Number of data files to include in each RMAN backup set.. [optional] if omitted the server will use the default value of 5  # noqa: E501
            check_logical (bool): True if extended block checking should be used for this linked database.. [optional] if omitted the server will use the default value of False  # noqa: E501
            encrypted_linking_enabled (bool): True if SnapSync data from the source should be retrieved through an encrypted connection. Enabling this feature can decrease the performance of SnapSync from the source but has no impact on the performance of VDBs created from the retrieved data.. [optional] if omitted the server will use the default value of False  # noqa: E501
            compressed_linking_enabled (bool): True if SnapSync data from the source should be compressed over the network. Enabling this feature will reduce network bandwidth consumption and may significantly improve throughput, especially over slow network.. [optional] if omitted the server will use the default value of True  # noqa: E501
            bandwidth_limit (int): Bandwidth limit (MB/s) for SnapSync and LogSync network traffic. A value of 0 means no limit.. [optional] if omitted the server will use the default value of 0  # noqa: E501
            number_of_connections (int): Total number of transport connections to use during SnapSync.. [optional] if omitted the server will use the default value of 1  # noqa: E501
            diagnose_no_logging_faults (bool): If true, NOLOGGING operations on this container are treated as faults and cannot be resolved manually.. [optional] if omitted the server will use the default value of True  # noqa: E501
            pre_provisioning_enabled (bool): If true, pre-provisioning will be performed after every sync.. [optional] if omitted the server will use the default value of False  # noqa: E501
            link_now (bool): True if initial load should be done immediately.. [optional] if omitted the server will use the default value of False  # noqa: E501
            force_full_backup (bool): Whether or not to take another full backup of the source database.. [optional] if omitted the server will use the default value of False  # noqa: E501
            double_sync (bool): True if two SnapSyncs should be performed in immediate succession to reduce the number of logs required to provision the snapshot. This may significantly reduce the time necessary to provision from a snapshot.. [optional] if omitted the server will use the default value of False  # noqa: E501
            rman_rate_in_mb (int): RMAN rate in megabytes to be used. This is the upper limit for bytes read so that RMAN does not consume excessive disk bandwidth and degrade online performance. (Oracle only) . [optional] if omitted the server will use the default value of 0  # noqa: E501
            skip_space_check (bool): Skip check that tests if there is enough space available to store the database in the Delphix Engine. The Delphix Engine estimates how much space a database will occupy after compression and prevents SnapSync if insufficient space is available. This safeguard can be overridden using this option. This may be useful when linking highly compressible databases.. [optional] if omitted the server will use the default value of False  # noqa: E501
            do_not_resume (bool): Indicates whether a fresh SnapSync must be started regardless if it was possible to resume the current SnapSync. If true, we will not resume but instead ignore previous progress and backup all datafiles even if already completed from previous failed SnapSync. This does not force a full backup, if an incremental was in progress this will start a new incremental snapshot.. [optional] if omitted the server will use the default value of False  # noqa: E501
            files_for_full_backup ([int]): List of datafiles to take a full backup of. This would be useful in situations where certain datafiles could not be backed up during previous SnapSync due to corruption or because they went offline.. [optional]  # noqa: E501
            log_sync_mode (str): LogSync operation mode for this database.. [optional] if omitted the server will use the default value of "UNDEFINED"  # noqa: E501
            log_sync_interval (int): Interval between LogSync requests, in seconds.. [optional] if omitted the server will use the default value of 5  # noqa: E501
            non_sys_username (str): Non-SYS database user to access this database. Only required for username-password auth (Single tenant only).. [optional]  # noqa: E501
            non_sys_password (str): Password for non sys user authentication (Single tenant only).. [optional]  # noqa: E501
            non_sys_vault_username (str): Delphix display name for the non sys vault user(Single tenant only).. [optional]  # noqa: E501
            non_sys_vault (str): The name or reference of the vault from which to read the database credentials (Single tenant only).. [optional]  # noqa: E501
            non_sys_hashicorp_vault_engine (str): Vault engine name where the credential is stored (Single tenant only).. [optional]  # noqa: E501
            non_sys_hashicorp_vault_secret_path (str): Path in the vault engine where the credential is stored (Single tenant only).. [optional]  # noqa: E501
            non_sys_hashicorp_vault_username_key (str): Hashicorp vault key for the username in the key-value store (Single tenant only).. [optional]  # noqa: E501
            non_sys_hashicorp_vault_secret_key (str): Hashicorp vault key for the password in the key-value store (Single tenant only).. [optional]  # noqa: E501
            non_sys_azure_vault_name (str): Azure key vault name (Single tenant only).. [optional]  # noqa: E501
            non_sys_azure_vault_username_key (str): Azure vault key for the username in the key-value store (Single tenant only).. [optional]  # noqa: E501
            non_sys_azure_vault_secret_key (str): Azure vault key for the password in the key-value store (Single tenant only).. [optional]  # noqa: E501
            non_sys_cyberark_vault_query_string (str): Query to find a credential in the CyberArk vault (Single tenant only).. [optional]  # noqa: E501
            fallback_username (str): The database fallback username. Optional if bequeath connections are enabled (to be used in case of bequeath connection failures). Only required for username-password auth.. [optional]  # noqa: E501
            fallback_password (str): Password for fallback username.. [optional]  # noqa: E501
            fallback_vault_username (str): Delphix display name for the fallback vault user.. [optional]  # noqa: E501
            fallback_vault (str): The name or reference of the vault from which to read the database credentials.. [optional]  # noqa: E501
            fallback_hashicorp_vault_engine (str): Vault engine name where the credential is stored.. [optional]  # noqa: E501
            fallback_hashicorp_vault_secret_path (str): Path in the vault engine where the credential is stored.. [optional]  # noqa: E501
            fallback_hashicorp_vault_username_key (str): Hashicorp vault key for the username in the key-value store.. [optional]  # noqa: E501
            fallback_hashicorp_vault_secret_key (str): Hashicorp vault key for the password in the key-value store.. [optional]  # noqa: E501
            fallback_azure_vault_name (str): Azure key vault name.. [optional]  # noqa: E501
            fallback_azure_vault_username_key (str): Azure vault key for the username in the key-value store.. [optional]  # noqa: E501
            fallback_azure_vault_secret_key (str): Azure vault key for the password in the key-value store.. [optional]  # noqa: E501
            fallback_cyberark_vault_query_string (str): Query to find a credential in the CyberArk vault.. [optional]  # noqa: E501
            ops_pre_log_sync ([SourceOperation]): Operations to perform after syncing a created dSource and before running the LogSync.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.network_performance_tool_api import NetworkPerformanceToolApi  # noqa: E501


class TestNetworkPerformanceToolApi(unittest.TestCase):
    """NetworkPerformanceToolApi unit test stubs"""

    def setUp(self):
        self.api = NetworkPerformanceToolApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_dsp_test(self):
        """Test case for create_dsp_test

        Create DSP Network Performance Test  # noqa: E501
        """
        pass

    def test_create_latency_test(self):
        """Test case for create_latency_test

        Create Latency Network Performance Test  # noqa: E501
        """
        pass

    def test_create_throughput_test(self):
        """Test case for create_throughput_test

        Create Throughput Network Performance Test  # noqa: E501
        """
        pass

    def test_get_dsp_test_result(self):
        """Test case for get_dsp_test_result

        Retrieve Network DSP Test Result  # noqa: E501
        """
        pass

    def test_get_latency_test_result(self):
        """Test case for get_latency_test_result

        Retrieve Network Latency Test Result  # noqa: E501
        """
        pass

    def test_get_throughput_test_result(self):
        """Test case for get_throughput_test_result

        Retrieve Network Throughput Test Result  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
